@@ -69,9 +69,6 @@ get_provider_features (GoaProvider *provider)
          GOA_PROVIDER_FEATURE_MAIL |
          GOA_PROVIDER_FEATURE_CALENDAR |
          GOA_PROVIDER_FEATURE_CONTACTS |
-#ifdef GOA_TELEPATHY_ENABLED
-         GOA_PROVIDER_FEATURE_CHAT |
-#endif
          GOA_PROVIDER_FEATURE_DOCUMENTS |
          GOA_PROVIDER_FEATURE_PHOTOS |
          GOA_PROVIDER_FEATURE_FILES |
@@ -130,11 +127,6 @@ get_scope (GoaOAuth2Provider *oauth2_provider)
          /* Google Cloud Print */
          "https://www.googleapis.com/auth/cloudprint "
 
-#ifdef GOA_TELEPATHY_ENABLED
-         /* Google Talk */
-         "https://www.googleapis.com/auth/googletalk "
-#endif
-
          /* Google Tasks - undocumented */
          "https://www.googleapis.com/auth/tasks";
 }
@@ -180,7 +172,6 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
   call = rest_proxy_new_call (proxy);
   rest_proxy_call_set_method (call, "GET");
   rest_proxy_call_add_param (call, "access_token", access_token);
-  rest_proxy_call_add_param (call, "fields", "email");
 
   if (!rest_proxy_call_sync (call, error))
     goto out;
@@ -289,7 +280,6 @@ build_object (GoaProvider         *provider,
   gboolean mail_enabled;
   gboolean calendar_enabled;
   gboolean contacts_enabled;
-  gboolean chat_enabled;
   gboolean documents_enabled;
   gboolean files_enabled;
   gboolean photos_enabled;
@@ -353,10 +343,6 @@ build_object (GoaProvider         *provider,
                                        contacts_enabled,
                                        FALSE);
 
-  /* Chat */
-  chat_enabled = g_key_file_get_boolean (key_file, group, "ChatEnabled", NULL);
-  goa_object_skeleton_attach_chat (object, chat_enabled);
-
   /* Documents */
   documents_enabled = g_key_file_get_boolean (key_file, group, "DocumentsEnabled", NULL);
   goa_object_skeleton_attach_documents (object, documents_enabled);
@@ -380,7 +366,6 @@ build_object (GoaProvider         *provider,
       goa_account_set_mail_disabled (account, !mail_enabled);
       goa_account_set_calendar_disabled (account, !calendar_enabled);
       goa_account_set_contacts_disabled (account, !contacts_enabled);
-      goa_account_set_chat_disabled (account, !chat_enabled);
       goa_account_set_documents_disabled (account, !documents_enabled);
       goa_account_set_photos_disabled (account, !photos_enabled);
       goa_account_set_files_disabled (account, !files_enabled);
@@ -398,10 +383,6 @@ build_object (GoaProvider         *provider,
                         "notify::contacts-disabled",
                         G_CALLBACK (goa_util_account_notify_property_cb),
                         (gpointer) "ContactsEnabled");
-      g_signal_connect (account,
-                        "notify::chat-disabled",
-                        G_CALLBACK (goa_util_account_notify_property_cb),
-                        (gpointer) "ChatEnabled");
       g_signal_connect (account,
                         "notify::documents-disabled",
                         G_CALLBACK (goa_util_account_notify_property_cb),
@@ -437,7 +418,6 @@ add_account_key_values (GoaOAuth2Provider  *oauth2_provider,
   g_variant_builder_add (builder, "{ss}", "MailEnabled", "true");
   g_variant_builder_add (builder, "{ss}", "CalendarEnabled", "true");
   g_variant_builder_add (builder, "{ss}", "ContactsEnabled", "true");
-  g_variant_builder_add (builder, "{ss}", "ChatEnabled", "true");
   g_variant_builder_add (builder, "{ss}", "DocumentsEnabled", "true");
   g_variant_builder_add (builder, "{ss}", "PhotosEnabled", "true");
   g_variant_builder_add (builder, "{ss}", "FilesEnabled", "true");
