@@ -73,7 +73,7 @@ static void goa_alarm_set_time (GoaAlarm *self, GDateTime *time);
 static void clear_wakeup_source_pointer (GoaAlarm *self);
 static guint signals[NUMBER_OF_SIGNALS] = { 0 };
 
-G_DEFINE_TYPE (GoaAlarm, goa_alarm, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_PRIVATE (GoaAlarm, goa_alarm, G_TYPE_OBJECT);
 
 static void
 goa_alarm_dispose (GObject *object)
@@ -152,8 +152,6 @@ goa_alarm_class_init (GoaAlarmClass *klass)
   object_class->get_property = goa_alarm_get_property;
   object_class->set_property = goa_alarm_set_property;
 
-  g_type_class_add_private (klass, sizeof (GoaAlarmPrivate));
-
   signals[FIRED] = g_signal_new ("fired",
                                  G_TYPE_FROM_CLASS (klass),
                                  G_SIGNAL_RUN_LAST,
@@ -281,14 +279,10 @@ on_timer_source_ready (GObject *stream, GoaAlarm *self)
 
   if (bytes_read < 0)
     {
-      if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        g_debug ("GoaAlarm: discontinuity detected from timer fd");
-      else
-        {
-          g_warning ("GoaAlarm: failed to read from timer fd: %s\n",
-                     error->message);
-          goto out;
-        }
+      g_warning ("GoaAlarm: failed to read from timer fd: %s\n",
+                 error->message);
+      g_error_free (error);
+      goto out;
     }
 
   if (bytes_read == sizeof (gint64))
@@ -304,7 +298,6 @@ on_timer_source_ready (GObject *stream, GoaAlarm *self)
   run_again = TRUE;
 out:
   g_rec_mutex_unlock (&self->priv->lock);
-  g_clear_error (&error);
   return run_again;
 }
 #endif /*HAVE_TIMERFD */
